[![Build Status](https://travis-ci.org/optimdata/pysigfox.svg?branch=master)](https://travis-ci.org/optimdata/pysigfox)
[![codecov](https://codecov.io/gh/optimdata/pysigfox/branch/master/graph/badge.svg)](https://codecov.io/gh/optimdata/pysigfox)
[![Documentation Status](https://readthedocs.com/projects/inuse-pysigfox/badge/?version=latest&token=9ae214b02c982eb9632fb078aabb9b47db229adae27be4357f4d0b381e8f0cff)](https://inuse-pysigfox.readthedocs-hosted.com/en/latest/?badge=latest)

# pysigfox

`pysigfox` is an unofficial client for the V2 [sigfox API](https://support.sigfox.com/apidocs). 

Inspired from [python-sigfox-backend-api](https://github.com/mjuenema/python-sigfox-backend-api).

## Resources

- [Official sigfox API documentation](https://support.sigfox.com/apidocs)
- [Documentation](https://inuse-pysigfox.readthedocs-hosted.com/en/latest/)